@@ -312,7 +312,7 @@
   effect         <- if(.is_model_regression(model)) !.is.prior_null(priors[["terms"]][["intercept"]]) else !.is.prior_null(priors[["mu"]])
   heterogeneity  <- if(!is.null(priors[["tau"]]))          !.is.prior_null(priors[["tau"]])
   bias           <- if(!is.null(priors[["bias"]]))         !.is.prior_null(priors[["bias"]])
-  hierarchical   <- if(!is.null(priors[["hierarchical"]])) !.is.prior_null(priors[["hierarchical"]])
+  hierarchical   <- if(!is.null(priors[["rho"]]))          !.is.prior_null(priors[["rho"]])
   baseline       <- if(!is.null(priors[["baseline"]]))     !.is.prior_null(priors[["baseline"]])
 
   # obtain the parameter types
@@ -338,29 +338,29 @@
     rownames(inference)[rownames(inference) == "intercept"] <- "Effect"
 
     # add marginal inference
+    parameters          <- NULL
     marginal_parameters <- NULL
     conditional_list    <- list()
 
     for(i in seq_along(priors[["terms"]])){
-      if(is.prior.spike_and_slab(priors[["terms"]][[i]]) || is.prior.mixture(priors[["terms"]][[i]])){
-        marginal_parameters <- c(marginal_parameters, .BayesTools_parameter_name(names(priors[["terms"]])[i]))
-        conditional_list[[.BayesTools_parameter_name(names(priors[["terms"]])[i])]] <- c(
-          if(names(priors[["terms"]])[i] != "intercept") .BayesTools_parameter_name("intercept"),
-          .BayesTools_parameter_name(names(priors[["terms"]])[i])
-        )
-      }
+      parameters <- c(parameters, .BayesTools_parameter_name(names(priors[["terms"]])[i]))
+      marginal_parameters <- c(marginal_parameters, .BayesTools_parameter_name(names(priors[["terms"]])[i]))
+      conditional_list[[.BayesTools_parameter_name(names(priors[["terms"]])[i])]] <- c(
+        if(names(priors[["terms"]])[i] != "intercept") .BayesTools_parameter_name("intercept"),
+        .BayesTools_parameter_name(names(priors[["terms"]])[i])
+      )
     }
 
-    inference_marginal <- BayesTools::as_marginal_inference(
+    inference_marginal <- suppressWarnings(BayesTools::as_marginal_inference(
       model               = model[["fit"]],
       marginal_parameters = marginal_parameters,
-      parameters          = names(conditional_list),
+      parameters          = parameters,
       conditional_list    = conditional_list,
       conditional_rule    = "OR",
       formula             = object[["formula"]],
       silent              = TRUE,
       force_plots         = TRUE
-    )
+    ))
   }else{
 
     # rename effect
@@ -484,9 +484,7 @@
     # add the terms
     for(i in seq_along(priors[["terms"]])){
       parameters_predictors <- c(parameters_predictors, .BayesTools_parameter_name(names(priors[["terms"]])[i]))
-      if(is.prior.spike_and_slab(priors[["terms"]][[i]]) || is.prior.mixture(priors[["terms"]][[i]])){
-        conditional_predictors[[.BayesTools_parameter_name(names(priors[["terms"]])[i])]] <- .BayesTools_parameter_name(names(priors[["terms"]])[i])
-      }
+      conditional_predictors[[.BayesTools_parameter_name(names(priors[["terms"]])[i])]] <- .BayesTools_parameter_name(names(priors[["terms"]])[i])
     }
 
     posteriors_predictors <- BayesTools::as_mixed_posteriors(
@@ -499,11 +497,12 @@
     if(length(conditional_predictors) > 0){
       posteriors_predictors_conditional <- list()
       for(i in seq_along(conditional_predictors)){
-        posteriors_predictors_conditional[[conditional_predictors[[i]]]] <- BayesTools::as_mixed_posteriors(
+        # suppress the not a conditional parameter warning in order to get "conditional estimates"
+        posteriors_predictors_conditional[[conditional_predictors[[i]]]] <- suppressWarnings(BayesTools::as_mixed_posteriors(
           model        = model[["fit"]],
           parameters   = names(conditional_predictors)[i],
           conditional  = conditional_predictors[[i]]
-        )[[names(conditional_predictors)[i]]]
+        ))[[names(conditional_predictors)[i]]]
       }
       posteriors_predictors_conditional <- BayesTools::transform_factor_samples(posteriors_predictors_conditional)
     }else{
